@@ -1,3 +1,4 @@
+from datetime import datetime
 import numpy
 import multiprocessing
 from threading import Thread
@@ -28,7 +29,7 @@ clr.AddReference("ThermoFisher.CommonCore.MassPrecisionEstimator")
 
 from ThermoFisher.CommonCore.RawFileReader import RawFileReaderAdapter
 from ThermoFisher.CommonCore.Data import ToleranceUnits, Extensions
-from ThermoFisher.CommonCore.Data.Business import MassOptions
+from ThermoFisher.CommonCore.Data.Business import MassOptions, FileHeaderReaderFactory
 from ThermoFisher.CommonCore.Data.FilterEnums import MSOrderType
 from System.Collections.Generic import List
 
@@ -59,6 +60,8 @@ class ImportMassSpectraThermoMSFileReader():
 
         self.iRawDataPlus = RawFileReaderAdapter.FileFactory(str(file_path))
 
+        self.iFileHeader = FileHeaderReaderFactory.ReadFile(str(file_path))
+
         # removing tmp file
 
         if isinstance(file_location, S3Path):
@@ -253,6 +256,10 @@ class ImportMassSpectraThermoMSFileReader():
 
         d_params['instrument_label'] = self.iRawDataPlus.GetInstrumentData().Name
 
+        date_time_str = self.iFileHeader.CreationDate.ToString()
+        
+        d_params["aquisition_time"] = datetime.strptime(date_time_str, "%m/%d/%Y %I:%M:%S %p")
+
         return d_params
 
     def get_average_mass_spectrum_by_scanlist(self, scans_list, auto_process: bool = True, ppm_tolerance: float = 5.0):
